<template>
    <div element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)">
        <el-dialog title="“三个一批”改革项目" :visible="visible" :before-close="handleClose" :close-on-click-modal="false"
            v-if="visible" width="60%" top="6vh" :class="[reqLoading ? 'dialog-box' : '']" append-to-body>
            <div>
                <div class="tabs-box">
                    <div :class="['tab-item', projectType === item.type ? 'active' : '']" v-for="item in tabsOptions"
                        :key="item.type" @click="handleClick(item.type)">
                        {{ item.name }}
                    </div>
                </div>
                <div class="search-box">
                    <el-row :gutter="24">
                        <el-col :span="7">
                            <div class="search-title">项目名称：</div>
                            <el-input v-model="queryParam.querys[0].value" placeholder="请输入内容" clearable></el-input>
                        </el-col>
                        <el-col :span="7">
                            <div class="search-title">{{ projectType === 1 ? '责任单位' : '主责单位' }}：</div>
                            <el-input v-model="queryParam.querys[1].value" placeholder="请输入内容" clearable></el-input>
                        </el-col>
                        <el-col :span="7" v-if="projectType !== 1">
                            <div class="search-title">专项小组：</div>
                            <dict-select :popperClass="`big-search-popper`" dictCode="zxxz" :hasDefaultOption="true" clearable
                                v-model="queryParam.querys[2].value" style="width: 100%" placeholder="请选择专项小组" />
                        </el-col>
                        <el-col :span="3">
                            <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch">
                                {{ this.$t('common.search') }}
                            </el-button>
                        </el-col>
                    </el-row>
                </div>
                <el-table :data="tableData" style="width: 100%" height="48vh" highlight-current-row
                    @current-change="handleCurrentChange1" :header-cell-style="{ textAlign: 'center' }"
                    :cell-style="{ textAlign: 'center' }" v-loading="loading" ref="myTable" element-loading-background="rgba(1, 33, 90, 1)">
                    <el-table-column type="index" label="序号" width="60" />
                    <el-table-column prop="projectName" label="项目名称" />
                    <el-table-column prop="unitName" :label="projectType === 1 ? '责任单位' : '主责单位'" width="160" />
                    <el-table-column v-if="projectType === 1" prop="leader" label="牵头市领导" />
                    <el-table-column v-else prop="groupName" label="专项小组" />
                </el-table>
            </div>
            <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="pageResult"
                @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            <div slot="footer" class="dialog-footer" :style="reqLoading ? 'position: relative;z-index: -1;' : ''">
                <el-button type="primary" @click="handlSaveUpdate">确 定</el-button>
                <el-button @click="handleClose">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import apiLsit from '@/api/effect'
import req from '@/request.js'
import utils from '@/utils.js'
import { type } from 'jquery'
const portal = window.context.portal
export default {
    name: 'selectProjectDialog',
    components: {
        pagination,
    },
    data() {
        return {
            loading: false,
            activeName: '1',
            reqLoading: false,
            markLoading: false,
            visible: false,
            tabsOptions: [
                {
                    name: '加快实施一批',
                    type: 1
                },
                {
                    name: '准备启动一批',
                    type: 2
                },
                {
                    name: '谋划储备一批',
                    type: 3
                },
            ],
            projectType: 1,
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'project_name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'unit_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'group_name_',
                        relation: 'AND',
                        value: '',
                    },
                ],
            },
            tableData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            currentRow: {},
            projectId: ''
        }
    },

    created() {
    },
    methods: {
        handleCurrentChange1(currentRow, oldCurrentRow) {
            this.currentRow = currentRow
        },
        open(id) {
            this.projectId = id || ''
            this.visible = true
            this.getTableData()
        },
        getTableData() {
            this.loading = true
            this.tableData = []
            let data = JSON.parse(JSON.stringify(this.queryParam))
            if (this.projectType === 1) {
                apiLsit.getQuickenData(data, res => {
                    this.pageResult.total = res.total
                    this.tableData = res.rows || []
                    this.$nextTick(() => {
                        let obj = this.tableData.find(item => item.id === this.projectId)
                        this.$refs.myTable.setCurrentRow(obj)
                    })
                    this.loading = false
                })
            } else {
                data.querys.push({
                    group: 'main',
                    operation: 'EQUAL',
                    parentGroup: '',
                    property: 'project_Type_',
                    relation: 'AND',
                    value: this.projectType,
                })
                apiLsit.getTwoBatchesData(data, res => {
                    this.pageResult.total = res.total
                    this.tableData = res.rows || []
                    this.$nextTick(() => {
                        let obj = this.tableData.find(item => item.id === this.projectId)
                        this.$refs.myTable.setCurrentRow(obj)
                    })
                    this.loading = false
                })
            }
        },
        handleClick(e) {
            if (e !== this.projectType) {
                this.projectType = e
                this.queryParam = {
                    pageBean: {
                        page: 1,
                        pageSize: 20,
                    },
                    querys: [
                        {
                            group: 'main',
                            operation: 'LIKE',
                            parentGroup: '',
                            property: 'project_name_',
                            relation: 'AND',
                            value: '',
                        },
                        {
                            group: 'main',
                            operation: 'LIKE',
                            parentGroup: '',
                            property: 'unit_Name_',
                            relation: 'AND',
                            value: '',
                        },
                        {
                            group: 'main',
                            operation: 'LIKE',
                            parentGroup: '',
                            property: 'group_name_',
                            relation: 'AND',
                            value: '',
                        }
                    ]
                }
                this.getTableData()
            }
        },
        handlSaveUpdate() {
            let { id, projectName } = this.currentRow
            this.$emit('handleCurrentChange1', { projectId: id, projectName })
            this.handleClose()
        },
        handleSearch() {
            this.getTableData()
        },
        handleCurrentChange(page) {
            this.queryParam.pageBean.page = page
            this.getTableData()
        },
        handleSizeChange(pageSize) {
            this.queryParam.pageBean.pageSize = pageSize
            this.getTableData()
        },
        // 关闭新增人员窗口
        handleClose() {
            this.projectType = 1
            this.tableData = []
            this.queryParam = {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'project_name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'unit_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'group_name_',
                        relation: 'AND',
                        value: '',
                    }
                ]
            }
            this.currentRow = {}
            this.visible = false
        },
    },
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

// 01215a 
// 006eff 
.tabs-box {
    display: flex;
    border-bottom: 1px solid #006eff;
    margin-bottom: 10px;

    .tab-item {
        cursor: pointer;
        margin-bottom: -1px;
        padding: 5px 10px;
        font-size: 15PX;
        border: 1px solid #006eff;
        background: #01215a;
        color: #fff;

        &:nth-child(2) {
            border-left: none;
            border-right: none;
        }

        &:nth-child(1) {
            border-top-left-radius: 5px;
        }

        &:nth-child(3) {
            border-top-right-radius: 5px;
        }

        &:hover {
            color: #409eff;
        }
    }

    .active {
        color: #409eff;
        border-bottom: none;
    }
}

.search-box {
    margin-bottom: 20px;

    .el-col {
        display: flex;
        align-items: center;

        .search-title {
            color: #fff;
            width: 120PX;
            font-size: 15PX;
        }

        /deep/.el-input__inner {
            color: #fff;
            font-size: 15PX;
            height: 30PX;
            line-height: 30PX;
            box-sizing: border-box;
            background: transparent;
            border: 1px solid #114385;
        }

    }
}

/deep/.el-dialog__header {
    background-color: #01215a;
    border-bottom: 1px solid #006eff;
    .el-dialog__title {
        color: #fff;
    }

    .el-dialog__close {
        background-color: #1790ff;
        color: #01215a !important;
    }
}

/deep/.el-table thead tr, 
/deep/.el-table thead tr th,
/deep/.el-table tr,
/deep/.el-table--striped .el-table__body tr.el-table__row--striped td.el-table__cell {
    background: #01215a !important;
    color: #fff;
}

/deep/.el-table td.el-table__cell,
/deep/.el-table th.el-table__cell.is-leaf,
/deep/.el-table td.el-table__cell {
    border-color: #006eff;
}
/deep/ .el-table--border::after,
/deep/ .el-table--group::after,
/deep/ .el-table::before {
    background-color: transparent;
}
/deep/.el-table th,
/deep/.el-table td {
    border: 1px solid #0251ba !important;
    border-right: none !important;
}
/deep/.el-table .el-table__cell.gutter  {
    border-top: none !important;
    border-bottom: none !important;
}
/deep/.el-pagination {
    color: #1790FF !important;
    font-size: 15PX;
    button {
        background-color: transparent !important;
        border: 1px solid #1790FF;
        .el-icon {
            color: #fff;
        }
    }
    .number {
        background-color: transparent !important;
        border: 1px solid #1790FF;
        color: #fff !important;
    }

    .active {
        background-color: #1790FF !important;
    }

    .el-pagination__sizes,
    .el-pagination__jump {
        display: none;
    }
}
/deep/.el-pagination__total {
    color: #1790FF !important;
    font-size: 15PX;
}

/deep/.el-dialog__footer {
    background-color: #01215a;
    .el-button--default {
        background-color: transparent;
        border: 1px solid #006eff;
        color: #fff;
    }
}

/deep/.el-table--enable-row-hover .el-table__body tr:hover > td.el-table__cell {
    background-color: #005db5;
}

/deep/.el-table th>.cell,
/deep/.el-table td>.cell {
    font-size: 16px;
    color: #fff;
}

/deep/.el-table--striped .el-table__body tr.el-table__row--striped.current-row td.el-table__cell,
/deep/.el-table__body tr.current-row>td.el-table__cell {
    background-color: #005db5;
}

/deep/.el-dialog__wrapper {
    overflow: hidden;
}



/deep/.el-dialog__body {
    max-height: 72vh !important;
    background-color: #01215a !important;
}


.dialog-footer {
    display: flex;
    justify-content: flex-end;
}

.input_placeholder {
    /deep/input::-webkit-input-placeholder {
        color: #606266;
        font-size: 12px;
    }
}

/deep/.el-table  {
    background: transparent;
}

/deep/.el-table ::-webkit-scrollbar,
/deep/::-webkit-scrollbar-track {
    background: #002970 !important;
}

// 设置滚动条的背景色和圆角
/deep/ .el-table__body-wrapper::-webkit-scrollbar-thumb  {
  background-color: #003185;
  border-radius: 8px;
}
//加载遮罩
/deep/.el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}

.dialog-box {
    /deep/.el-dialog__body {
        overflow: hidden;
    }
}
</style>